==> haskell-unicode-show-0.1.1.0-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.1.0
visibility:           public
id:                   unicode-show-0.1.1.0-6QFpdYVP2p5KgbNPjdGhkb
key:                  unicode-show-0.1.1.0-6QFpdYVP2p5KgbNPjdGhkb
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           whosekiteneverfly@gmail.com
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  77c815f1e211afb5274a818b49bc6976
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-show-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-show-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unicode-show-0.1.1.0
hs-libraries:         HSunicode-show-0.1.1.0-6QFpdYVP2p5KgbNPjdGhkb
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.1.0-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 unicode-show
version:              0.1.1.0
visibility:           public
id:                   unicode-show-0.1.1.0-GaKSBhyRWXoDkkehdO5Uw5
key:                  unicode-show-0.1.1.0-GaKSBhyRWXoDkkehdO5Uw5
license:              BSD-3-Clause
copyright:            2016 Takayuki Muranushi
maintainer:           whosekiteneverfly@gmail.com
author:               Takayuki Muranushi
homepage:             http://github.com/haskell-jp/unicode-show#readme
synopsis:             print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.

    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.

    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.

category:             Text
abi:                  4c8496e8a59489946f549b855cd3c963
exposed:              True
exposed-modules:      Text.Show.Unicode
import-dirs:          /usr/lib/ghc-9.0.2/site-local/unicode-show-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/unicode-show-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/unicode-show-0.1.1.0
hs-libraries:         HSunicode-show-0.1.1.0-GaKSBhyRWXoDkkehdO5Uw5
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock

haddock-html:         /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
